# pyvulncheck

pyvulncheck is an open-source tool designed for detecting vulnerabilities in Python packages, drawing inspiration from the capabilities of [govulncheck](https://pkg.go.dev/golang.org/x/vuln/cmd/govulncheck). It uses [deps.dev Open API](https://docs.deps.dev/api/v3alpha/) to detect vulnerabilities.
